/*
 * Copyright 2011 E-Government Innovation Center (EGIZ)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package at.gv.zustellung.zusemsg.config;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import at.gv.util.config.EgovUtilPropertiesConfiguration;
import at.gv.util.config.EgovUtilConfiguration;
import at.gv.zustellung.zusemsg.wsdl.client.attachments.MailBody;

public class PropertiesZuse2AppConfiguration implements Zuse2AppConfiguration {

Logger log = LoggerFactory.getLogger(PropertiesZuse2AppConfiguration.class);
	
	private Properties props;
	private String configDir = null;
	
	private MailBody mailBody = null;

	private EgovUtilConfiguration zuseUtilConfiguration = null;
	
	public PropertiesZuse2AppConfiguration(String propertiesFileName) throws IOException {
		if (propertiesFileName == null) {
			throw new NullPointerException("Parameter propertiesFile must not be null.");
		}
		File propertiesFile = new File(propertiesFileName);
		FileInputStream fis = new FileInputStream(propertiesFile);
		this.configDir = propertiesFile.getParentFile().getAbsolutePath();
		log.trace("ZuseMsg Configuration directory: " + this.configDir);
		this.props = new Properties();
		props.load(fis);
		
		// initialize
		initialize();
	}
	
	public PropertiesZuse2AppConfiguration(Properties props, String configDir) throws IOException {
		if (props == null) {
			throw new NullPointerException("Parameter props must not be null.");
		}
		if (configDir == null) {
			throw new NullPointerException("Argument 'configDir' must not be null.");
		}
		this.configDir = configDir;
		this.props = props;
		
		// initialize
		initialize();
	}
	
	private void initialize() throws IOException {
		// initialize mailbody
		if (props.getProperty("zusemsg.zuse2app.mail.content.file") == null) {
			log.debug("No mail body for zuse2app defined. Skipping mailbody initialization.");
		} else {
			String mailBodyContentType = props.getProperty("zusemsg.zuse2app.mail.content.type");
			String mailBodyFileString = props.getProperty("zusemsg.zuse2app.mail.content.file");
			File tmpFile = new File(mailBodyFileString);
			File mailBodyFile = null;
			if(tmpFile.isAbsolute()) {
				mailBodyFile = tmpFile;
			} else {
				mailBodyFile = new File(this.configDir, mailBodyFileString);
			}
			this.mailBody = new MailBody(mailBodyContentType, new FileInputStream(mailBodyFile));
			
			// initialize zuseutil configuration
			zuseUtilConfiguration = new EgovUtilPropertiesConfiguration(this.props, this.configDir); 
		}
	}

	@Override
  public String getZuse2AppMOASSServiceURL() {
	  return props.getProperty("zusemsg.zuse2app.moass.ws.url");
  }

	@Override
  public String getZuse2AppMOASSKeyIdentifier() {
		return props.getProperty("zusemsg.zuse2app.moass.keyidentifier");	
  }
	
	@Override
  public String getZuse2AppMailHost() {
	  return props.getProperty("zusemsg.zuse2app.mail.host");
  }

	@Override
  public String getZuse2AppMailPort() {
	  return props.getProperty("zusemsg.zuse2app.mail.port");
  }

	@Override
  public String getZuse2AppMailSenderName() {
	  return props.getProperty("zusemsg.zuse2app.mail.sender.name");
  }

	@Override
  public String getZuse2AppMailSenderMailAddress() {
	  return props.getProperty("zusemsg.zuse2app.mail.sender.address");
  }

	@Override
  public String getZuse2AppMailSubject() {
	  return props.getProperty("zusemsg.zuse2app.mail.subject");
  }

	@Override
  public MailBody getZuse2AppMailBody() {
	  return this.mailBody;
  }

	@Override
  public String getZuse2AppMOASPServiceURL() {
		return props.getProperty("zusemsg.zuse2app.moasp.ws.url");
  }

	@Override
  public String getZuse2AppMOASPTrustProfile() {
		return props.getProperty("zusemsg.zuse2app.moasp.trustprofile");
  }

	@Override
  public EgovUtilConfiguration getZuseUtilConfiguration() {
	  return this.zuseUtilConfiguration;
  }
	
}
