/*
 * Copyright 2011 E-Government Innovation Center (EGIZ)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package at.gv.zustellung.zusemsg.wsdl.client.attachments;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.activation.DataSource;

import at.gv.util.MiscUtil;

public class BinaryAttachment implements DataSource {

	private String name = null;
	private String contentType = null;
	//private InputStream content = null;
	private ByteArrayOutputStream bos = null;
	
	//private Logger log = LoggerFactory.getLogger(BinaryAttachment.class);
	
	public BinaryAttachment(String name, String contentType, InputStream content) throws IOException {
		if (name == null) {
			throw new NullPointerException("Parameter 'name' must not be null.");
		}
		if (contentType == null) {
			throw new NullPointerException("Parameter 'contentType' must not be null.");
		}
		if (content == null) {
			throw new NullPointerException("Parameter 'content' must not be null.");
		}
		this.name = name;
		this.contentType = contentType;
		//this.content = content;
		this.bos = new ByteArrayOutputStream();
		MiscUtil.copyStream(content, bos);
	}
	
	public String getContentType() {
		return this.contentType;
	}

	public byte[] getRawContent() {
		return bos.toByteArray();
	}
	
	public InputStream getInputStream() throws IOException {
		return new ByteArrayInputStream(bos.toByteArray()); //this.content;
	}

	public String getName() {
		return this.name;
	}

	public OutputStream getOutputStream() throws IOException {
		return null;
	}
	
	public long getSize() {
		return bos.size();
	}
	
}
