/*
 * Copyright 2011 E-Government Innovation Center (EGIZ)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package at.gv.zustellung.zusemsg.wsdl.client.attachments;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Arrays;
import java.util.List;

import javax.activation.DataSource;

import at.gv.util.MiscUtil;

public class MailBody implements DataSource {

	public final static String TEXT_HTML = "text/html";
	public final static String TEXT_PLAIN = "text/plain";
	
	//private final static String NAME = "mailBody";
	
	public final static List<String> SUPPORTED_TYPES = Arrays.asList(new String[] { TEXT_HTML, TEXT_PLAIN });
	
	private String contentType = null;
	//private InputStream content = null;
	private ByteArrayOutputStream bos = null;
	
	public MailBody(String contentType, InputStream content) throws IOException {
		if (!SUPPORTED_TYPES.contains(contentType)) {
			throw new IOException("Content-Type '" + contentType + "' not supported for mail content.");
		}
		this.contentType = contentType;
		if (content == null) {
			throw new NullPointerException("Argument 'content' must not be null.");
		}
		//this.content = content;
		this.bos = new ByteArrayOutputStream();
		MiscUtil.copyStream(content, bos);
	}
	
	public String getContentType() {
	  return this.contentType;
  }

	public InputStream getInputStream() throws IOException {
		return new ByteArrayInputStream(bos.toByteArray()); //this.content;
  }

	public String getName() {
	  if (TEXT_HTML.equals(this.contentType)) {
	  	return "mailBody.html";
	  } else if (TEXT_PLAIN.equals(this.contentType)) {
	  	return "mailBody.txt";
	  } else {
	  	return "mailBody.dat";
	  }
  }

	public OutputStream getOutputStream() throws IOException {
	  throw new IOException("This method is not supported.");
  }
	
}
