/*
 * Copyright 2011 E-Government Innovation Center (EGIZ)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package at.gv.zustellung.zusemsg.wsdl.client.handler;


import java.io.ByteArrayInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.transform.Source;
import javax.xml.transform.TransformerException;
import javax.xml.transform.stream.StreamSource;
import javax.xml.ws.handler.LogicalHandler;
import javax.xml.ws.handler.LogicalMessageContext;
import javax.xml.ws.handler.MessageContext;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.w3c.dom.Element;

import at.gv.util.DOMUtils;
import at.gv.util.MiscUtil;
import at.gv.zustellung.zusemsg.config.ZuseMsgConfiguration;
import at.gv.zustellung.zusemsg.xsd.zuse.DeliveryNotification;

public class Zuse2AppSignatureCreationHandler implements LogicalHandler<LogicalMessageContext> {

	private Logger log = LoggerFactory.getLogger(Zuse2AppSignatureCreationHandler.class);
	
	private ZuseMsgConfiguration config = null;
	
	public Zuse2AppSignatureCreationHandler(ZuseMsgConfiguration config) {
		if (config == null) {
			throw new NullPointerException("Argument 'config' must not be null.");
		}
		this.config = config;
	}
	
  @Override
  public void close(MessageContext context) {
  }

  @Override
  public boolean handleFault(LogicalMessageContext context) {
    return true;
  }

  @Override
  public boolean handleMessage(LogicalMessageContext context) {

  	// handle only outgoing messages
  	log.trace("Starting Zuse2App Signature Creation Handler");
  	Boolean outboundProperty = (Boolean) context.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
  	log.trace("Outbound message: " + outboundProperty);
	  if(outboundProperty != Boolean.TRUE) {
	  	return true;    
	  }
  	
	  // check if we have a payload
    Source source = context.getMessage().getPayload();
    if (source == null) {
    	log.trace("No payload found. Skipping signature generation.");
      return true;
    }
    try {

    	byte[] rawNotification = MiscUtil.sourceToByteArray(source);
    	
    	// unmarshall
    	JAXBContext jaxbContext = JAXBContext.newInstance(DeliveryNotification.class.getPackage().getName());
    	DeliveryNotification deliveryNotification = (DeliveryNotification) jaxbContext.createUnmarshaller().unmarshal(new ByteArrayInputStream(rawNotification));

    	Zuse2AppSignatureCreator signatureCreator = new Zuse2AppSignatureCreator(this.config);
			Element response = signatureCreator.createSignature(deliveryNotification);
      Source resSource = new StreamSource(new ByteArrayInputStream(DOMUtils.serializeNode(response, "UTF-8")));
      // set updated payload
      context.getMessage().setPayload(resSource);
      
      return true;
    } catch (FileNotFoundException e) {
      log.warn("Error signing notification.", e);
      throw new RuntimeException(e);
    } catch (IOException e) {
    	log.warn("Error signing notification.", e);
    	throw new RuntimeException(e);
    } catch (TransformerException e) {
    	log.warn("Error signing notification.", e);
    	throw new RuntimeException(e);
    } catch (JAXBException e) {
    	log.warn("Error signing notification.", e);
    	throw new RuntimeException(e);
    } catch (Zuse2AppSignatureException e) {
    	log.warn("Error signing notification.", e);
    	throw new RuntimeException(e);
    }
  }
}
